import type { MockOptions } from './options';
export declare type Mock<T> = T;
export declare enum Mode {
    EXPECT = 0,
    CALL = 1
}
export declare const setMode: (mode: Mode) => void;
/**
 * Create a type safe mock.
 *
 * @see {@link when} Set expectations on the mock using `when`.
 *
 * @param options Configure the options for this specific mock, overriding any
 *   defaults that were set with {@link setDefaults}.
 * @param options.unexpectedProperty Controls what happens when an unexpected
 *   property is accessed.
 * @param options.concreteMatcher The matcher that will be used when one isn't
 *   specified explicitly.
 * @param options.exactParams Controls whether the number of received arguments
 *   has to match the expectation.
 *
 * @example
 * const fn = mock<() => number>();
 *
 * when(() => fn()).thenReturn(23);
 *
 * fn() === 23;
 */
export declare const mock: <T>({ unexpectedProperty, concreteMatcher, exactParams, }?: MockOptions) => T;
