import type { Expectation } from '../expectation/expectation';
import type { ReturnValue } from '../expectation/repository/return-value';
import type { ConcreteMatcher } from '../mock/options';
import type { Property } from '../proxy';
/**
 * An expectation has to be built incrementally, starting first with the property
 * being accessed inside {@link createStub}, then any arguments passed to it, and ending
 * it with the returned value from {@link createReturns}.
 */
export interface PendingExpectation {
    setProperty(prop: Property): void;
    setArgs(args: any[] | undefined): void;
    finish(returnValue: ReturnValue): Expectation;
    /**
     * Used by `pretty-format`.
     */
    toJSON(): string;
}
export declare type ExpectationFactory = (property: Property, args: any[] | undefined, returnValue: ReturnValue, concreteMatcher: ConcreteMatcher, exactParams: boolean) => Expectation;
export declare class PendingExpectationWithFactory implements PendingExpectation {
    private createExpectation;
    private concreteMatcher;
    private exactParams;
    private args;
    private property;
    constructor(createExpectation: ExpectationFactory, concreteMatcher: ConcreteMatcher, exactParams: boolean);
    setProperty(value: Property): void;
    setArgs(value: any[] | undefined): void;
    finish(returnValue: ReturnValue): Expectation;
    toJSON(): string;
}
